@@ -5,15 +5,15 @@ use strict;
 
 =head1 NAME
 
-Test::Command - Test external commands (nearly) as easily as loaded modules.
+Test::Command::Simple - Test external commands (nearly) as easily as loaded modules.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use base 'Test::Builder::Module';
 use IPC::Open3;
@@ -27,6 +27,7 @@ our @EXPORT = qw(
     stderr
     rc
     run_ok
+    exit_status
     );
 
 =head1 SYNOPSIS
